@@ -2,7 +2,7 @@
 # written by Ralf Biehl at the Forschungszentrum Jülich ,
 # Jülich Center for Neutron Science 1 and Institute of Complex Systems 1
 #    Jscatter is a program to read, analyse and plot data
-#    Copyright (C) 2015-2019  Ralf Biehl
+#    Copyright (C) 2015-2021  Ralf Biehl
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -97,7 +97,7 @@ def showExampleList():
     """
     Show an updated list of all examples.
 
-    Currently availible examples ::
+    Currently, availible examples ::
 
     """
     print('Example path : ', _expath)
@@ -113,7 +113,7 @@ showExampleList.__doc__ += _examplelist + '\n'
 
 def runExample(example, usempl=False):
     """
-    Run example.
+    Run example by number or name.
 
     Example and saved files go to JscatterExamples/example_name in the current working directory.
 
@@ -124,42 +124,53 @@ def runExample(example, usempl=False):
     usempl : bool, default False
         For using mpl set to True
 
+    Examples
+    -------- ::
+
+     import jscatter as js
+     js.examples.runExample('daily_use')
+
     """
     if not graceplot.GraceIsInstalled:
         usempl = True
 
+    exfiles = _getexamples()
     if isinstance(example, numbers.Integral):
-        exfiles = _getexamples()
         example = exfiles[example]
         print('-----------------------------------')
         print(example)
+    else:
+        for ef in exfiles:
+            if example in ef:
+                example = ef
+                break
 
     cwd = os.getcwd()
-    # change path to write into subfolder
-    exname = os.path.split(example[:-3])[1]
-    temppath = os.path.join(cwd, 'jscatterExamples', exname)
-    if not os.path.exists(temppath):
-        os.makedirs(temppath)
-    os.chdir(temppath)
-    with open(example) as f:
-        if usempl:
-            if 'grace' in example or 'makeJ' in example:
-                print('This example is not for mpl.')
-                return
-
-            file = f.read()
-            file = _multiple_replace2(file, {r'\.grace\(\d\.?\d?,\s?\d\.?\d?\)': ".mplot()"})
-            file = _multiple_replace(file, mplotreplace)
-        else:
-            file=f.read()
-        if graceplot._headless:
-            print('headless')
-            file = _multiple_replace(file, headlessreplace)
-            # append this to close all opened mpl figures
-            file+='\n\njs.mpl.close("all")\n\n'
-
     # try and in anny case go back to cwd
     try:
+        # change path to write into subfolder
+        head, exname = os.path.split(os.path.splitext(example)[0])
+        temppath = os.path.join(cwd, 'jscatterExamples', exname)
+        if not os.path.exists(temppath):
+            os.makedirs(temppath)
+        os.chdir(temppath)
+        with open(example) as f:
+            if usempl:
+                if 'grace' in example or 'makeJ' in example:
+                    print('This example is not for mpl.')
+                    return
+                file = f.read()
+                file = _multiple_replace2(file, {r'\.grace\(\d\.?\d?,\s?\d\.?\d?\)': ".mplot()"})
+                file = _multiple_replace(file, mplotreplace)
+            else:
+                file=f.read()
+            if graceplot._headless:
+                print('headless')
+                file = _multiple_replace(file, headlessreplace)
+                # append this to close all opened mpl figures
+                file+='\n\njs.mpl.close("all")\n\n'
+
+        # now do it
         exec(file, {})
     finally:
         os.chdir(cwd)
@@ -188,10 +199,17 @@ def showExample(example='.', usempl=False):
     if not graceplot.GraceIsInstalled:
         usempl = True
 
+    exfiles = _getexamples()
     if isinstance(example, numbers.Integral):
-        exfiles = _getexamples()
         example = exfiles[example]
-    examplepath = os.path.join(_expath, example)
+        print('-----------------------------------')
+        print(example)
+    else:
+        for ef in exfiles:
+            if example in ef:
+                example = ef
+                break
+    examplepath = example
 
     if usempl:
         if 'grace' in example:
